@@ -96,7 +96,8 @@ import sys
 import tempfile
 import time
 
-from mysqldb import MySQLDB
+#from mysqldb import MySQLDB
+from pymysql_utils.pymysql_utils import MySQLDB
 
 
 # Add json_to_relation source dir to $PATH
@@ -123,7 +124,7 @@ class EngagementComputer(object):
     # Recognizing fake course names:
     FAKE_COURSE_PATTERN = re.compile(r'([Tt]est|[Ss]and[Bb]ox|[Dd]avid|[Dd]emo|Humaanities|SampleUniversity|[Jj]ane|ZZZ|Education/EDUC115N[^\s]*\s)')
     
-    def __init__(self, coursesStartYearsArr, dbHost, dbName, tableName, mySQLUser=None, mySQLPwd=None, courseToProfile=None):
+    def __init__(self, coursesStartYearsArr, dbHost, dbName, tableName, openMySQLDB=None, mySQLUser=None, mySQLPwd=None, courseToProfile=None):
         '''
         Sets up one session-accounting run through a properly filled table (as
         per file level comment above.
@@ -153,6 +154,7 @@ class EngagementComputer(object):
         self.tableName = tableName
         self.mySQLUser = mySQLUser
         self.mySQLPwd  = mySQLPwd
+        self.db        = openMySQLDB
         self.courseToProfile = courseToProfile
         self.coursesStartYearsArr = coursesStartYearsArr
         # To keep track of which course runtimes
@@ -173,7 +175,12 @@ class EngagementComputer(object):
                 self.mySQLPwd = ''
         # Place to hold all stats for one class
         self.classStats = {}
-        self.db = MySQLDB(host=self.dbHost, user=self.mySQLUser, passwd=self.mySQLPwd, db=dbName)
+        # If no open db connector was passed in, open one:
+        if self.db is None:
+            self.db = MySQLDB(host=self.dbHost, user=self.mySQLUser, passwd=self.mySQLPwd, db=dbName)
+            self.openOwnDB = True
+        else:
+            self.openOwnDB = False
         # Ensure that the CourseRuntimes table exists:
         self.getCourseRuntime('fakename', testOnly=True)        
         
@@ -209,11 +216,11 @@ class EngagementComputer(object):
             queryEndTimeReported = False
             if self.courseToProfile is None:
                 # Profile all courses:
-                queryIterator = self.db.query('SELECT course_display_name, anon_screen_name, time, isVideo FROM %s ORDER BY course_display_name, anon_screen_name, time;' % 
-                                              self.tableName)
+                queryIterator = self.db.query('use %s; SELECT course_display_name, anon_screen_name, time, isVideo FROM %s ORDER BY course_display_name, anon_screen_name, time;' % 
+                                              self.dbName, self.tableName)
             else:
-                queryIterator = self.db.query('SELECT course_display_name, anon_screen_name, time, isVideo FROM %s WHERE course_display_name = "%s" ORDER BY anon_screen_name, time;' % 
-                                              (self.tableName, self.courseToProfile))
+                queryIterator = self.db.query('use %s; SELECT course_display_name, anon_screen_name, time, isVideo FROM %s WHERE course_display_name LIKE "%s" ORDER BY anon_screen_name, time;' % 
+                                              (self.dbName, self.tableName, self.courseToProfile))
             for activityRecord in queryIterator:
                 if not queryEndTimeReported:
                     self.log('Query done in %s' % str(datetime.timedelta(seconds=(time.time() - queryStartTime))))
@@ -300,7 +307,11 @@ class EngagementComputer(object):
         finally:
             if self.db is not None:
                 try:
-                    self.db.close()
+                    # If creator of this instance passed an open
+                    # db into this instance, don't close that db.
+                    # But if we opened one ourselves, close it:
+                    if self.openOwnDB:
+                        self.db.close()
                 except Exception as e:
                     self.logErr('Could not close activities db: ' % `e`);
 
@@ -544,7 +555,7 @@ class EngagementComputer(object):
                  outFileWeeklyEffort: shows sum of weekly efforts for each student, week by week.
         @rtype: (string,string,string)
         '''
-        if courseToProfile is None:
+        if self.courseToProfile is None:
             # Analysis was requested for all courses.
             # The summary goes into one file:
             outFileSummary = tempfile.NamedTemporaryFile(suffix='_engagementAllCourses_summary.csv', delete=False)
@@ -555,7 +566,7 @@ class EngagementComputer(object):
         else:
             # Analysis was requested for a single course.
             # The summary goes into /tmp/engagement_<courseNameNoSpacesOrSlashes>_summary.csv:
-            courseNameNoSpaces = string.replace(string.replace(courseToProfile,' ',''), '/', '_')
+            courseNameNoSpaces = string.replace(string.replace(self.courseToProfile,' ',''), '/', '_')
             outFileSummary = tempfile.NamedTemporaryFile(suffix='_engagement_%s_summary.csv' % courseNameNoSpaces, delete=False)
             outFileAll     = tempfile.NamedTemporaryFile(suffix='_engagement_%s_allData.csv' % courseNameNoSpaces, delete=False)
             outFileWeeklyEffort = tempfile.NamedTemporaryFile(suffix='_engagement_%s_weeklyEffort.csv' % courseNameNoSpaces, delete=False)
@@ -612,8 +623,8 @@ if __name__ == '__main__':
         
     # -------------- Run the Computation ---------------
     #***** Switch between testing and real:
-    #testing = True
-    testing = False
+    testing = True
+    #testing = False
     if testing:
         db = 'test'
     else:
